@@ -25,7 +25,7 @@ class PyPiSearch:
         if ul is None:
             return NoResultsFound(keyword)
         else:
-            return list(cls().parse_pypi_results(html, keyword))
+            return list(cls().parse_pypi_results(ul))
 
     async def pypi_get_results(self, keyword):
         search_term = keyword.replace(" ", "+")
@@ -35,30 +35,26 @@ class PyPiSearch:
             results = await such_ergebnis.text()
         return results
 
-    def parse_pypi_results(self, raw_html, keyword):
-
-        if ul is None:
-            return NoResultsFound(keyword)
-        else:
-            result_block = ul.find_all('li')
-            for result in result_block:
-                link = result.find('a', href=True)['href']
-                name = result.find('span', attrs={'class': 'package-snippet__name'})
-                version = result.find('span', attrs={'class': 'package-snippet__version'})
-                description = result.find('p', attrs={'class': 'package-snippet__description'})
-                release = result.find('time')
-                if release is not None:
-                    release = release.decode_contents().strip("\n \n")
-                if name is not None:
-                    name = name.decode_contents()
-                if version is not None:
-                    version = version.decode_contents()
-                if description is not None:
-                    description = description.decode_contents()
-                if name and link:
-                    yield PyPiProject(
-                        {"name": name, "description": description, "version": version, "released": release,
-                         "link": "https://pypi.org" + link})
+    @classmethod
+    def parse_pypi_results(cls, ul):
+        result_block = ul.find_all('li')
+        for result in result_block:
+            link = result.find('a', href=True)['href']
+            name = result.find('span', attrs={'class': 'package-snippet__name'})
+            version = result.find('span', attrs={'class': 'package-snippet__version'})
+            description = result.find('p', attrs={'class': 'package-snippet__description'})
+            release = result.find('time')
+            if release is not None:
+                release = release.decode_contents().strip("\n \n")
+            if name is not None:
+                name = name.decode_contents()
+            if version is not None:
+                version = version.decode_contents()
+            if description is not None:
+                description = description.decode_contents()
+            if name and link:
+                yield PyPiProject({"name": name, "description": description, "version": version, "released": release,
+                                   "link": "https://pypi.org" + link})
 
 
 class PyPiProject:
@@ -102,8 +98,8 @@ class SearchError:
         self.args = args
 
     @property
-    def error(cls):
-        return str(cls.args)
+    def error(self):
+        return str(self.args)
 
 
 class NoResultsFound(SearchError):
